#
# spec file for package smlnj
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           smlnj
Version:        110.99
Release:        bp155.2.25
Summary:        Standard ML of New Jersey
License:        BSD-3-Clause
Group:          Development/Languages/Other
URL:            https://www.smlnj.org/
Source:         smlnj-%{version}.tar.xz
Source1:        pack_new_version.sh
Source2:        urlgetter.sh
Source3:        smlnj-rpmlintrc
Patch1:         MLRISC.diff
Patch2:         smlnj-kernel-6.x.patch
BuildRequires:  gcc-c++
ExclusiveArch:  %{ix86} x86_64 ppc

%description
SML/NJ is an interactive compiler for the Standard ML Programming
Language (1997 Revision).

%prep
%setup -q
tar -xzf config.tgz
# place urlgetter
cp %{SOURCE2} .
%patch2 -p1

mkdir base
cd base
tar -xzf ../runtime.tgz
tar -xzf ../MLRISC.tgz
%patch1

%build
# remove reference to remote d/l
echo "SRCARCHIVEURL=/" > ./config/srcarchiveurl
export BUILDDIR="%{_builddir}/%{name}-%{version}"
export URLGETTER="%{_sourcedir}/urlgetter.sh"

CFLAGS="%{optflags}" config/install.sh -default 64

%install
mkdir -p %{buildroot}%{_libdir}/smlnj
cp -a bin lib %{buildroot}%{_libdir}/smlnj
mkdir -p %{buildroot}%{_bindir}
for f in %{buildroot}%{_libdir}/smlnj/bin/*; do
  sed -i -e "s,$PWD,%{_libdir}/smlnj," $f
  ln -sf ${f#%{buildroot}} %{buildroot}%{_bindir}
done
for f in %{buildroot}%{_libdir}/smlnj/bin/.*-sml; do
  sed -i -e "s,$PWD,%{_libdir}/smlnj," $f
done

# ship required env var
# todo: move this to the build, if possible
# especially as there is a conflict
# if you installed both 32-bit and 64-bit archs
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
echo "export SMLNJ_HOME=%{_libdir}/smlnj" > %{buildroot}%{_sysconfdir}/profile.d/%{name}.sh

%files
%doc %{version}-*
%{_bindir}/asdlgen
%{_bindir}/ml-antlr
%{_bindir}/ml-build
%{_bindir}/ml-burg
%{_bindir}/ml-lex
%{_bindir}/ml-makedepend
%ifarch %{ix86}
%{_bindir}/ml-nlffigen
%endif
%{_bindir}/ml-ulex
%{_bindir}/ml-yacc
%{_bindir}/sml
%{_libdir}/smlnj
# todo: cook it into the build, if possible
%config %{_sysconfdir}/profile.d/%{name}.sh

%changelog
* Wed Nov  2 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add smlnj-kernel-6.x.patch: Detect kernel 6.x.
* Tue Mar  2 2021 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Download the source code via https:// for authenticity.
* Fri Jan  1 2021 Avindra Goolcharan <avindra@opensuse.org>
- Correct typo in eXene source module extension
* Sun Dec 27 2020 Avindra Goolcharan <avindra@opensuse.org>
- add SMLNJ_HOME env var profile
  * fixes user-facing issue when importing code from std lib
- update pack_new_version.sh
  * use source structure from readme
  * configure curl/script for re-use and speed
  * switch to xz for compression (from bzip2)
- explicitly list binaries in spec
- format MLRISC.diff to match build directory
- remove obsolete minmem file
- add smlnj-rpmlintrc
* Fri Dec 25 2020 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 110.99
  * support for 64-bit architectures added
  * many changes since 2017, see upstream:
    https://www.smlnj.org/dist/working/110.99/HISTORY.html
- update pack_new_version.sh
  * add 64bit support tarball
  * add asdl tarball
  * remove non-linux platform docs
- ran spec-cleaner
* Thu Jul  6 2017 idonmez@suse.com
- Update to version 110.81
  Successor ML:
  * The 110.81 release adds additional support for Successor ML
    syntactic extensions. It is now possible to use record-punning
    syntax in expressions (as well as in patterns).
  * And we have added support for do syntax in let bindings.
  * We have also changed the way that Successor ML features are
    enabled from the REPL. Instead of assigning true to the
    Control.succML variable, one should use the function
    Control.setSuccML is used to enable or disable Successor ML.
  Compiler
  * This version eliminates dependencies on FLINT types in the
    front end. In particular, uses of PlambdaType have been eliminated.
  SML/NJ Library:
  * Added the JSONUtil module to the JSON library.
  ml-lpt
  * Added --debug command-line option to ml-antlr. This flag causes
    ml-antlr to generate debug actions that print the left-hand-side
    non-terminal of the production.
  * Added %%tokentype directive to ml-antlr, which allows user-defined
    datatypes to be used to represent tokens.
  MLRISC:
  * Changed the interface to AMD64Gen; the signBit and negateSignBit
    callback functions now return an MLTree.rexp (instead of a label).
  Bugfixes:
  * 129	Symbolic identifiers are allowed as strids
  * 149	Datatype replication exposes hidden constructors
  * 153	Enabling Successor ML features is delayed
  * 175	Executable stack on Linux
  * 179	ml-ulex writing debug messages to stdOut
  * Parser bugfix: we now allow `*` as a field label in record-punning patterns.
- Drop smlnj-linux-4.0.patch, upstream.
* Wed May 20 2015 dimstar@opensuse.org
- Add smlnj-linux-4.0.patch: Fix build with Linux kernel 4.x.
* Tue Mar 27 2012 idonmez@suse.com
- Update to version 110.74
  Compiler:
  * Added cuprit tracking
  SML/NJ Library:
  * Added hash-table-based implementation of sets to the utility
    library.
  * Added new S-expression library for I/O of semi-structured data.
  * Fixed bug in JSON scanner.
  Fixed Bugs:
  * Incorrect type inference with functor taking/producing
    polymorphic type (bug #60)
  * Errors in ml-lpt manual (bug #74)
  * blastWrite crashes (bug #76)
  * strange error message for syntax error (bug #77)
  * Installation fails on Linux 3.0 (bug #80)
  * sml/nj does not work with Linux 3.0 (bug #81)
  * No support for Kernel 3.x (bug #83)
- Drop config.diff, runtime.diff
- Add pack_new_version.sh to pack new versions
* Mon Feb 16 2009 schwab@suse.de
- Update to version 110.69.
* Thu Oct 30 2008 schwab@suse.de
- Fix embedded paths.
* Wed Feb 13 2008 schwab@suse.de
- Update to version 110.67.
* Fri Aug 10 2007 schwab@suse.de
- Update to version 110.65.
* Thu Mar  1 2007 schwab@suse.de
- Hack to build as non-root.
* Tue Nov 21 2006 schwab@suse.de
- Update to version 110.60.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jul  1 2005 schwab@suse.de
- Update to version 110.54.
* Fri Feb 11 2005 schwab@suse.de
- Update to version 110.52.
* Tue Nov 16 2004 schwab@suse.de
- Update to version 110.50.
* Thu Aug  5 2004 schwab@suse.de
- Update to version 110.47.
* Mon May 17 2004 schwab@suse.de
- Update to version 110.45.
- Also build on ppc.
* Mon May 12 2003 schwab@suse.de
- Fix file list.
* Thu Nov 14 2002 schwab@suse.de
- Fix invalid token pasting.
* Sat Feb 10 2001 schwab@suse.de
- Initial version 110.0.7.
